Methodology
===========

This section concerns technologies chosen for this project, user interface design
and implementation.

.. toctree::
   :maxdepth: 2

   choices
   arch
   uc-anal-design/index
   database/index
   ux
   process
